Craft Archives
==============

Craft Archives is a Python package to manage interaction with software
archives on behalf of tools using the Craft Parts framework.

Craft Archives provides a set of common interfaces to define the locations
of software archives, install packages and verify their integrity.

The aim of this package is to provide a uniform, extensible set of interfaces
that other tools and packages can use to work with software archives.

This package is most useful for implementers of tools using the Craft Parts
framework that need to provide support for additional software archives.
